@@ -1,4 +1,4 @@
-
+from typing import Union
 
 from MSApi.ObjectMS import ObjectMS, check_init
 
@@ -16,13 +16,5 @@ class Attribute(ObjectMS):
         return self._json.get('name')
 
     @check_init
-    def get_type(self) -> str:
-        return self._json.get('type')
-
-    @check_init
-    def is_required(self) -> bool:
-        return self._json.get('required')
-
-    @check_init
-    def get_description(self) -> str:
-        return self._json.get('description')
+    def get_value(self) -> Union[str]:
+        return self._json.get('value')
