@@ -1,10 +1,10 @@
 from typing import Optional
 from datetime import datetime
 
-from MSApi.documents.DocumentMS import DocumentMS
+from MSApi.documents import DocumentMS, check_init
 from MSApi.MSLowApi import MSLowApi, error_handler, caching
 from MSApi.State import State
-from MSApi.documents.ProcessingOrder import ProcessingOrder
+from MSApi.documents import ProcessingOrder
 
 
 class Processing(DocumentMS):
@@ -39,3 +39,7 @@ class Processing(DocumentMS):
         response = MSLowApi.auch_post(f'entity/demand', json=self.get_json(), **kwargs)
         error_handler(response)
         self._json = response.json()
+
+    @check_init
+    def get_state(self) -> Optional[State]:
+        return self._get_optional_object('state', State)
