@@ -7,7 +7,7 @@ from MSApi.State import State
 from MSApi.Organization import Account
 from MSApi.Project import Project
 from MSApi.Attribute import Attribute
-from MSApi.documents import Processing
+from MSApi.documents import Processing, ProcessingPlan
 
 
 class ProcessingOrder(ObjectMS):
@@ -97,6 +97,10 @@ class ProcessingOrder(ObjectMS):
             return Account(result)
         return None
 
+    @check_init
+    def get_processing_plan(self) -> ProcessingPlan:
+        return ProcessingPlan(self._json.get('processingPlan'))
+
     @check_init
     def gen_processings(self):
         for attr in self._json.get('processings', []):
